@@ -1,9 +1,12 @@
 use std::time::Duration;
 
 use kafka::{client::RequiredAcks, producer::Producer};
-use serde_derive::Deserialize;
+use serde::Deserialize;
 
-use crate::pipelining::{BootstrapResult, SinkProvider, StageReceiver};
+use crate::{
+    pipelining::{BootstrapResult, SinkProvider, StageReceiver},
+    utils::WithUtils,
+};
 
 use super::run::producer_loop;
 
@@ -21,24 +24,29 @@ pub struct Config {
     pub paritioning: Option<PartitionStrategy>,
 }
 
-impl SinkProvider for Config {
+impl SinkProvider for WithUtils<Config> {
     fn bootstrap(&self, input: StageReceiver) -> BootstrapResult {
-        let mut builder = Producer::from_hosts(self.brokers.clone());
+        let mut builder = Producer::from_hosts(self.inner.brokers.clone());
 
-        if let Some(timeout) = &self.ack_timeout_secs {
+        if let Some(timeout) = &self.inner.ack_timeout_secs {
             builder = builder
                 .with_ack_timeout(Duration::from_secs(*timeout))
                 .with_required_acks(RequiredAcks::One)
         };
 
         let producer = builder.create()?;
-        let topic = self.topic.clone();
+        let topic = self.inner.topic.clone();
         let partitioning = self
+            .inner
             .paritioning
             .clone()
             .unwrap_or(PartitionStrategy::Random);
+
+        let utils = self.utils.clone();
+
         let handle = std::thread::spawn(move || {
-            producer_loop(input, producer, topic, partitioning).expect("producer loop failed")
+            producer_loop(input, producer, topic, partitioning, utils)
+                .expect("producer loop failed")
         });
 
         Ok(handle)
